@@ -23,7 +23,7 @@ from io import StringIO
 pd.set_option("mode.chained_assignment",None)
 pd.set_option("display.notebook_repr_html",True)
 pd.set_option("display.width",None)
-pd.set_option('display.expand_frame_repr', False)
+pd.set_option('display.expand_frame_repr', True)
 pd.set_option('display.max_rows', 500)
 pd.set_option('display.max_columns', 10)
 pd.set_option('display.width', 250)
@@ -39,7 +39,7 @@ def getCaseNumber(text: str):
     try:
         county: str = re.search(r'(?:County\: )(\d{2})(?:Case)', str(text)).group(1).strip()
         case_num: str = county + "-" + re.search(r'(\w{2}\-\d{4}-\d{6}.\d{2})', str(text)).group(1).strip() 
-        return county + "-" + case_num
+        return case_num
     except (IndexError, AttributeError):
         return ""
 
@@ -1108,8 +1108,6 @@ def parseCases(conf):
         b['FeeCodes'] = b['FeeOutputs'].map(lambda x: x[4])
         b['FeeSheet'] = b['FeeOutputs'].map(lambda x: x[5])
         b['PaymentToCERV'] = b['AllPagesText'].map(lambda x: getPaymentToRestore(x))
-        b['NEED_CERV'] = b.CERVConvictions.map(lambda x: bool(len(x)>0))
-        b.PaymentToCERV[b['NEED_CERV']==False] = np.nan
 
 
         feesheet = b['FeeOutputs'].map(lambda x: x[6]) 
@@ -1169,7 +1167,7 @@ def parseCases(conf):
             arch.dropna(inplace=True)
             arch.to_pickle(archive_out,compression="xz")
 
-        b.drop(columns=['AllPagesText','CaseInfoOutputs','ChargesOutputs','FeeOutputs','TotalD999','ChargesTable','FeeSheet','NEED_CERV'],inplace=True)
+        b.drop(columns=['AllPagesText','CaseInfoOutputs','ChargesOutputs','FeeOutputs','TotalD999','ChargesTable','FeeSheet'],inplace=True)
         
         b.fillna('',inplace=True)
         charges.fillna('',inplace=True)
@@ -1300,7 +1298,7 @@ def parseCaseInfo(conf):
         b['TotalAmtDue'] = b['TotalAmtDue'].map(lambda x: pd.to_numeric(x,'coerce'))
         b['TotalBalance'] = b['TotalBalance'].map(lambda x: pd.to_numeric(x,'coerce'))
 
-        b.drop(columns=['AllPagesText','CaseInfoOutputs','Totals','NEED_CERV'],inplace=True)
+        b.drop(columns=['AllPagesText','CaseInfoOutputs','Totals'],inplace=True)
         
         b.fillna('',inplace=True)
         newcases = [cases, b]
@@ -1356,9 +1354,15 @@ def parse(conf, method, *args):
 
         write(conf, pd.Series(alloutputs))
 
+    allout = pd.Series(alloutputs).infer_objects()
+    try:
+        allout = allout.map(lambda x: x.values[0])
+    except AttributeError:
+        pass
+
     if print_log == True:
         log_complete(conf, start_time)
-    return alloutputs
+    return allout
 
 def log_complete(conf, start_time):
     path_in = conf['input_path']
